Discrete statistical tests for single-cell data analysis.
This module implements tests for categorical and count data, such as Chi-square and Fisher’s exact tests.
Functions
- chi_
square_ test - Performs a chi-square test for independence on a 2x2 contingency table
- fisher_
exact_ sparse - Perform Fisher’s Exact Test across all genes in a sparse matrix.
- fisher_
exact_ test - Fisher’s Exact Test for 2x2 contingency table.