t_test_sparse

Function t_test_sparse 

pub fn t_test_sparse<T, N, I>(
    matrix: SparseMatrixRef<'_, T, N, I>,
    group1_indices: &[usize],
    group2_indices: &[usize],
    test_type: TTestType,
) -> Result<Vec<TestResult<f64>>>
Perform t-tests on a sparse matrix represented by raw components.

This version is agnostic of the matrix container and can be used with raw vectors.