pub struct SparseMatrixRef<'a, T, N, I> {
pub maj_ind: &'a [N],
pub min_ind: &'a [I],
pub val: &'a [T],
pub n_rows: usize,
pub n_cols: usize,
}Expand description
A lightweight reference-based representation of a sparse matrix (CSR or CSC).
This structure is designed to be agnostic of the underlying container and can be easily used with raw vectors from other crates or FFI (like PyO3).
Fields
maj_ind: &'a [N]Major indices (e.g., indptr in CSR/CSC)
min_ind: &'a [I]Minor indices (e.g., column indices in CSR, row indices in CSC)
val: &'a [T]The actual values in the matrix
n_rows: usizeNumber of rows in the matrix
n_cols: usizeNumber of columns in the matrix
Implementations
Sourceimpl<'a, T, N, I> SparseMatrixRef<'a, T, N, I>
impl<'a, T, N, I> SparseMatrixRef<'a, T, N, I>